import mongoose, {ObjectId, mongo} from 'mongoose';
import dotenv from 'dotenv';
import UserModel from './models/user';
import ArtistModel from './models/artist';
import AlbumModel from './models/album';
import TrackModel from './models/track';
dotenv.config();

mongoose.connect(process.env.MONGO_URL + '/MyPlayer');

const db = mongoose.connection;

db.once('open', async () => {
	try {
		await db.dropCollection('users');
		await db.dropCollection('artists');
		await db.dropCollection('albums');
		await db.dropCollection('tracks');
	} catch (e) {
		console.log('Collections were not present, skipping drop...');
	}

	await UserModel.create(
		{
			username: 'alen',
			password: '1',
			role: 'Admin',
		},
		{
			username: 'danil',
			password: '2',
			role: 'User',
		}
	);

	const drakeId = new mongoose.Types.ObjectId();
	const eminemId = new mongoose.Types.ObjectId();
	const kizaruId = new mongoose.Types.ObjectId();
	const snoopId = new mongoose.Types.ObjectId();

	await ArtistModel.create(
		{
			_id: drakeId,
			info: 'Aubrey Drake Graham is a Canadian rapper and singer. An influential global figure in contemporary popular music, Drake has been credited for popularizing singing and R&B sensibilities in hip hop.',
			name: 'Drake',
			photo: 'drake.jpg',
		},
		{
			_id: eminemId,
			info: 'Marshall Bruce Mathers III, known professionally as Eminem, is an American rapper, songwriter, and record producer. He is credited with popularizing hip hop in middle America and is critically acclaimed as one of the greatest rappers of all time.',
			name: 'Eminem',
			photo: 'eminem.png',
		},
		{
			_id: kizaruId,
			info: 'Рэп-исполнитель новой волны, проживающий в Барселоне',
			name: 'Kizaru',
			photo: 'kizaru.jpg',
		},
		{
			_id: snoopId,
			info: 'Calvin Cordozar Broadus Jr. (born October 20, 1971), known professionally as Snoop Dogg is an American rapper and actor.',
			name: 'Snoop Dogg',
			photo: 'snoop.jpg',
		}
	);

	const firstAlbumId = new mongoose.Types.ObjectId();
	const secondAlbumId = new mongoose.Types.ObjectId();
	const thirdAlbumId = new mongoose.Types.ObjectId();
	const fourthAlbumId = new mongoose.Types.ObjectId();
	const fifthAlbumId = new mongoose.Types.ObjectId();

	await AlbumModel.create(
		{
			_id: firstAlbumId,
			artist: drakeId,
			image: 'album1.jpg',
			year: 2001,
			name: 'Room for Improvement',
		},
		{
			_id: secondAlbumId,
			artist: drakeId,
			image: 'album2.jpg',
			year: 2005,
			name: 'Comeback Season',
		},
		{
			_id: thirdAlbumId,
			artist: eminemId,
			image: 'album3.jpg',
			year: 2011,
			name: 'One fortune',
		},
		{
			_id: fourthAlbumId,
			artist: kizaruId,
			image: 'kizaruAlbum.jpg',
			year: 2005,
			name: 'Bandana',
		},
		{
			_id: fifthAlbumId,
			artist: snoopId,
			image: 'snoopAlbum.jpg',
			year: 2005,
			name: 'High',
		}
	);

	await TrackModel.create(
		{
			album: firstAlbumId,
			duration: '2:56',
			name: 'sfdg12',
		},
		{
			album: firstAlbumId,
			duration: '2:56',
			name: 'sdfsadfsad',
		},
		{
			album: firstAlbumId,
			duration: '2:36',
			name: '12312',
		},
		{
			album: firstAlbumId,
			duration: '2:56',
			name: 'sadf',
		},
		{
			album: firstAlbumId,
			duration: '2:56',
			name: 'gfjgfh',
		},
		{
			album: secondAlbumId,
			duration: '3:10',
			name: 'hgjfgh',
		},
		{
			album: secondAlbumId,
			duration: '3:10',
			name: 'sadfasd',
		},
		{
			album: secondAlbumId,
			duration: '3:10',
			name: '21312312',
		},
		{
			album: secondAlbumId,
			duration: '3:10',
			name: 'sadfasfasd',
		},
		{
			album: secondAlbumId,
			duration: '3:10',
			name: 'asdvdsa',
		},
		{
			album: thirdAlbumId,
			duration: '3:10',
			name: 'hgjfgh',
		},
		{
			album: thirdAlbumId,
			duration: '3:10',
			name: 'sadfasd',
		},
		{
			album: thirdAlbumId,
			duration: '3:10',
			name: '21312312',
		},
		{
			album: thirdAlbumId,
			duration: '3:10',
			name: 'sadfasfasd',
		},
		{
			album: thirdAlbumId,
			duration: '3:10',
			name: 'asdvdsa',
		},
		{
			album: fourthAlbumId,
			duration: '3:10',
			name: 'hgjfgh',
		},
		{
			album: fourthAlbumId,
			duration: '3:10',
			name: 'sadfasd',
		},
		{
			album: fourthAlbumId,
			duration: '3:10',
			name: '21312312',
		},
		{
			album: fourthAlbumId,
			duration: '3:10',
			name: 'sadfasfasd',
		},
		{
			album: fourthAlbumId,
			duration: '3:10',
			name: 'asdvdsa',
		},
		{
			album: fifthAlbumId,
			duration: '3:10',
			name: 'hgjfgh',
		},
		{
			album: fifthAlbumId,
			duration: '3:10',
			name: 'sadfasd',
		},
		{
			album: fifthAlbumId,
			duration: '3:10',
			name: '21312312',
		},
		{
			album: fifthAlbumId,
			duration: '3:10',
			name: 'sadfasfasd',
		},
		{
			album: fifthAlbumId,
			duration: '3:10',
			name: 'asdvdsa',
		}
	);

	db.close();
});
